Progress

Struct Progress 

pub struct Progress {
    pub total: usize,
    /* private fields */
}

Fields

total: usize

Implementations

Source

impl Progress

pub fn new(total: usize, interval: ProgressInterval) -> Progress

pub fn set_prefix(&mut self, msg: String)

pub fn set_autoprint(&mut self, enabled: bool)

true causes Progress to print to stdout, false causes it to not print.

pub fn set_same_line(&mut self, same_line: bool)

Print updates on the same line in the terminal, as a typical progress bar would. In some CI environments (like AWS CodeBuild) this should be disabled in order for progress updates to appear.

pub fn set(&mut self, new_current: usize) -> bool

Assign a value to the current amount. Returns true if a new line should be printed based on the chosen interval.

pub fn inc(&mut self) -> bool

Increment the current count by 1. Returns true if a new line should be printed based on the chosen interval.

pub fn current_count(&self) -> usize

Get the current count.

pub fn msg(&self) -> String

Get the current progress message.

pub fn finish_msg(&self) -> String